<#

.NAME       : Get-WMIabc 

.VERSION       : 1.3 

.LAST UPDATED       : 2/24/2013 
Fixed help --- help Get-WMIabc -full -- now functional.  (1.1)
Changed Write-Host to Write-Output -- Better way to display 'date' information.  (1.2)
Script is AllSigned ready -- Only scripts signed by a trusted publisher can be run.  (1.3)

.AUTHOR       : J. Perry Stonne 

.LINK       : http://www.twitter.com/webstonne 

.COMMENTS      : This script is based on a template created by Don Jones.

SEE      : Turn PowerShell Commands into Reusable CLI and GUI Tools 
http://channel9.msdn.com/Events/TechEd/NorthAmerica/2012?sort=sequential&direction=desc&term=powershell&page=2

* Do Not Use In A Production Environment Until You Have Tested *
* Thoroughly In A Lab Environment. Use At Your Own Risk. If *
* You Do Noy Understand What This Script Does Or How It Works, *
* Do Not Use It Outside Of A Secure, Test Setting. * 

#>


Function Get-WMIabc {
<#
.SYNOPSIS
  This script retrieves WMI information from one or several machines. It converts three dates into readable form:
   Last Boot Time, BIOS Release Date, OS Installation Date.
 .DESCRIPTION
 This script uses Windows Management Instrumenatation (WMI) to retrieve information from one or several machines
 using the ComputerName parameter or an IP Address.
 .PARAMETER ComputerName
 Standard parameter
 .EXAMPLE
Get-WMIabc | Get-Content "M:\computer.txt"
This will use a text list of several machines to query
 .EXAMPLE
Get-WMIabc | Get-Content "M:\computer.csv"
This will use a comma seperated value spreadsheet (Excel) of several machines to query
 .EXAMPLE
Get-WMIabc -ComputerName JoeComputer
Query single machine
 .EXAMPLE
Get-WMIabc -ComputerName 51.80.37.212
Query machine using IP address
 .EXAMPLE
Get-WMIabc -ComputerName 51.80.37.212, JoeComputer
Query Two (or more) machines
#>

[CmdLetBinding()]
param(
    [Parameter(Mandatory=$True,ValueFromPipeline=$True)]
    [string[]]$ComputerName 
)
BEGIN{}
PROCESS {
   foreach ($computer in $ComputerName) {
      $os = Get-WMIObject -Class Win32_OperatingSystem -ComputerName $computer
      $time = $os.LastBootUpTime 
      $bios = Get-WMIObject -Class Win32_Bios -ComputerName $computer
      $cs = Get-WMIObject -Class Win32_ComputerSystem -ComputerName $computer
      $props = @{'ComputerName'=$computer;
           'OSVersion'=$os.version;
           'SPVersion'=$os.servicepackmajorversion;
		   'OSSerialNumber'=$os.SerialNumber;
		   'OperatingSystemSKU'=$os.OperatingSystemSKU;
		   'BIOSSerial'=$bios.serialnumber;
		   'Description'=$bios.Description;
           '__SERVER'=$bios.PSComputerName;
           'Model'=$cs.model;
           'Manufacturer'=$cs.manufacturer
            }
		  
           $obj = New-Object -TypeName PSObject $props

      Write-OutPut $obj
      Write-Output " "
      Write-Output "Last Boot Time"
      [System.Management.ManagementDateTimeconverter]::ToDateTime($time) 
      Write-Output "BIOS Release Date"
      [Management.ManagementDateTimeConverter]::ToDateTime($bios.ReleaseDate) 
      Write-Output "OS Installation Date" 
      [System.Management.ManagementDateTimeconverter]::ToDateTime($os.InstallDate)

}
}
END{}
}

# SIG # Begin signature block
# MIIELQYJKoZIhvcNAQcCoIIEHjCCBBoCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUneSXlWkQk1zzHYuzUiACeLRI
# xsmgggI9MIICOTCCAaagAwIBAgIQ2C5F7bzMI5lFJ8q4tP0IATAJBgUrDgMCHQUA
# MCYxJDAiBgNVBAMTG0ouIFBlcnJ5IFN0b25uZSAod2Vic3Rvbm5lKTAeFw0xMjA3
# MjIwMTUzNTVaFw0zOTEyMzEyMzU5NTlaMCYxJDAiBgNVBAMTG0ouIFBlcnJ5IFN0
# b25uZSAod2Vic3Rvbm5lKTCBnzANBgkqhkiG9w0BAQEFAAOBjQAwgYkCgYEAozWI
# e3IU5jvmYq4H9GYR4THwvcpgvsjFuDGdFSKZdeKx9tXfK6LSLkYgEQQuob1Y6mbP
# /TdOnfJH+9rl8657QZL7dawLBDXV8YPT4rTZRI5Nc7skvHORXzCe+Zj7oR6AmjCy
# JHz4k36DxcKS+6EQTU9vHHInKohI9laFCyAlqRcCAwEAAaNwMG4wEwYDVR0lBAww
# CgYIKwYBBQUHAwMwVwYDVR0BBFAwToAQwZRzfqa/hype8qB+7VG03KEoMCYxJDAi
# BgNVBAMTG0ouIFBlcnJ5IFN0b25uZSAod2Vic3Rvbm5lKYIQ2C5F7bzMI5lFJ8q4
# tP0IATAJBgUrDgMCHQUAA4GBAKCeJeUkOW4a/Igi1Qc9VK8H+Q4ZvFRuuFJLhTcA
# cCktQmzLawdYGs6tkKQttsmx53S1lbES5BB96UcEFBB2koAHd14DHokSNiwq/7UT
# KFRX5IAFG7+yhBjGz3xZwBpusVr6COZveGEk8i01gL74I1xlAfi8yJYdG7P2szpA
# 5sl+MYIBWjCCAVYCAQEwOjAmMSQwIgYDVQQDExtKLiBQZXJyeSBTdG9ubmUgKHdl
# YnN0b25uZSkCENguRe28zCOZRSfKuLT9CAEwCQYFKw4DAhoFAKB4MBgGCisGAQQB
# gjcCAQwxCjAIoAKAAKECgAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYK
# KwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFCN3tEdo
# EuDmDh5OFPnUF2GxZgXVMA0GCSqGSIb3DQEBAQUABIGAaM3hlqPmfZuhjFrFyrnO
# Z/alQI/QRHJlCZVSDI/RtIN0Yo7HECiAysXqaRpC7y8LTpqVjumQIrbP4QHxnndr
# ao6Zm9CxuoRyUuyD06PMNPNmszfO2K2qKpNfXlSDIdbzaYO4s/fAH2C+xqLrno/p
# moeLk6Hi/ix+TTDLZz/prmg=
# SIG # End signature block
